@@ -1,7 +1,7 @@
 /*
  * This file is part of BOINC.
  * http://boinc.berkeley.edu
- * Copyright (C) 2020 University of California
+ * Copyright (C) 2021 University of California
  *
  * BOINC is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License
@@ -40,10 +40,12 @@ import androidx.fragment.app.replace
 import androidx.lifecycle.lifecycleScope
 import edu.berkeley.boinc.adapter.NavDrawerListAdapter
 import edu.berkeley.boinc.adapter.NavDrawerListAdapter.NavDrawerItem
+import edu.berkeley.boinc.attach.AttachAccountManagerActivity
 import edu.berkeley.boinc.attach.SelectionListActivity
 import edu.berkeley.boinc.client.ClientStatus
 import edu.berkeley.boinc.client.IMonitor
 import edu.berkeley.boinc.client.Monitor
+import edu.berkeley.boinc.client.MonitorAsync
 import edu.berkeley.boinc.databinding.MainBinding
 import edu.berkeley.boinc.ui.eventlog.EventLogActivity
 import edu.berkeley.boinc.utils.*
@@ -66,7 +68,7 @@ class BOINCActivity : AppCompatActivity() {
         override fun onServiceConnected(className: ComponentName, service: IBinder) {
             // This is called when the connection with the service has been established, getService returns
             // the Monitor object that is needed to call functions.
-            monitor = IMonitor.Stub.asInterface(service)
+            monitor = MonitorAsync(IMonitor.Stub.asInterface(service))
             mIsBound = true
             determineStatus()
         }
@@ -75,23 +77,22 @@ class BOINCActivity : AppCompatActivity() {
             // This should not happen
             monitor = null
             mIsBound = false
+
             Log.e(Logging.TAG, "BOINCActivity onServiceDisconnected")
         }
     }
     private val mClientStatusChangeRec: BroadcastReceiver = object : BroadcastReceiver() {
         override fun onReceive(context: Context, intent: Intent) {
-            if (Logging.VERBOSE) {
-                Log.d(Logging.TAG, "BOINCActivity ClientStatusChange - onReceive()")
-            }
+            Log.d(Logging.TAG, "BOINCActivity ClientStatusChange - onReceive()")
+
             determineStatus()
         }
     }
     private val ifcsc = IntentFilter("edu.berkeley.boinc.clientstatuschange")
 
     public override fun onCreate(savedInstanceState: Bundle?) {
-        if (Logging.DEBUG) {
-            Log.d(Logging.TAG, "BOINCActivity onCreate()")
-        }
+        Log.d(Logging.TAG, "BOINCActivity onCreate()")
+
         super.onCreate(savedInstanceState)
         binding = MainBinding.inflate(layoutInflater)
         setContentView(binding.root)
@@ -148,7 +149,7 @@ class BOINCActivity : AppCompatActivity() {
         }
         if (item != null) {
             dispatchNavBarOnClick(item, true)
-        } else if (Logging.WARNING) {
+        } else {
             Log.w(Logging.TAG, "onCreate: fragment selection returned null")
         }
 
@@ -162,26 +163,23 @@ class BOINCActivity : AppCompatActivity() {
     }
 
     override fun onDestroy() {
-        if (Logging.DEBUG) {
-            Log.d(Logging.TAG, "BOINCActivity onDestroy()")
-        }
+        Log.d(Logging.TAG, "BOINCActivity onDestroy()")
+
         doUnbindService()
         super.onDestroy()
     }
 
     override fun onNewIntent(intent: Intent) {
-        if (Logging.DEBUG) {
-            Log.d(Logging.TAG, "BOINCActivity onNewIntent()")
-        }
+        Log.d(Logging.TAG, "BOINCActivity onNewIntent()")
+
         // onNewIntent gets called if activity is brought to front via intent, but was still alive, so onCreate is not called again
         // getIntent always returns the intent activity was created of, so this method is the only hook to receive an updated intent
         // e.g. after (not initial) project attach
         super.onNewIntent(intent)
         // navigate to explicitly requested fragment (e.g. after project attach)
         val id = intent.getIntExtra("targetFragment", -1)
-        if (Logging.DEBUG) {
-            Log.d(Logging.TAG, "BOINCActivity onNewIntent() for target fragment: $id")
-        }
+        Log.d(Logging.TAG, "BOINCActivity onNewIntent() for target fragment: $id")
+
         val item: NavDrawerItem? = if (id < 0) {
             // if ID is -1, go to default
             mDrawerListAdapter.getItem(0)
@@ -198,9 +196,8 @@ class BOINCActivity : AppCompatActivity() {
     }
 
     override fun onPause() { // gets called by system every time activity loses focus.
-        if (Logging.VERBOSE) {
-            Log.v(Logging.TAG, "BOINCActivity onPause()")
-        }
+        Log.d(Logging.TAG, "BOINCActivity onPause()")
+
         super.onPause()
         unregisterReceiver(mClientStatusChangeRec)
     }
@@ -229,16 +226,14 @@ class BOINCActivity : AppCompatActivity() {
     private fun dispatchNavBarOnClick(item: NavDrawerItem?, init: Boolean) {
         // update the main content by replacing fragments
         if (item == null) {
-            if (Logging.WARNING) {
-                Log.w(Logging.TAG, "dispatchNavBarOnClick returns, item null.")
-            }
+            Log.w(Logging.TAG, "dispatchNavBarOnClick returns, item null.")
+
             return
         }
-        if (Logging.DEBUG) {
             Log.d(Logging.TAG,
                     "dispatchNavBarOnClick for item with id: ${item.id} title: ${item.title}" +
                             " is project? ${item.isProjectItem}")
-        }
+
         val ft = supportFragmentManager.beginTransaction()
         var fragmentChanges = false
         if (init) {
@@ -272,24 +267,21 @@ class BOINCActivity : AppCompatActivity() {
                         tvVersion.text = getString(R.string.about_version,
                                 packageManager.getPackageInfo(packageName, 0).versionName)
                     } catch (e: PackageManager.NameNotFoundException) {
-                        if (Logging.WARNING) {
                             Log.w(Logging.TAG, "version name not found.")
-                        }
                     }
                     returnB.setOnClickListener { dialog.dismiss() }
                     dialog.show()
                 }
                 R.string.menu_eventlog -> startActivity(Intent(this, EventLogActivity::class.java))
                 R.string.projects_add -> startActivity(Intent(this, SelectionListActivity::class.java))
+                R.string.attachproject_acctmgr_header -> startActivity(Intent(this, AttachAccountManagerActivity::class.java))
                 R.string.tab_preferences -> {
                     ft.replace<SettingsFragment>(R.id.frame_container)
                     fragmentChanges = true
                 }
-                else -> if (Logging.ERROR) {
-                    Log.d(Logging.TAG,
+                else -> Log.e(Logging.TAG,
                             "dispatchNavBarOnClick() could not find corresponding fragment for" +
-                                    " ${item.title}")
-                }
+                            " ${item.title}")
             }
         } else {
             // ProjectDetailsFragment. Data shown based on given master URL
@@ -304,9 +296,7 @@ class BOINCActivity : AppCompatActivity() {
             mDrawerListAdapter.selectedMenuId = item.id //highlight item persistently
             mDrawerListAdapter.notifyDataSetChanged() // force redraw
         }
-        if (Logging.DEBUG) {
-            Log.d(Logging.TAG, "displayFragmentForNavDrawer() " + item.title)
-        }
+        Log.d(Logging.TAG, "displayFragmentForNavDrawer() " + item.title)
     }
 
     // tests whether status is available and whether it changed since the last event.
@@ -322,11 +312,10 @@ class BOINCActivity : AppCompatActivity() {
                 if (numberProjectsInNavList != monitor!!.projects.size) {
                     numberProjectsInNavList = mDrawerListAdapter.compareAndAddProjects(monitor!!.projects)
                 }
+                mDrawerListAdapter.updateUseAccountManagerItem()
             }
         } catch (e: Exception) {
-            if (Logging.ERROR) {
-                Log.e(Logging.TAG, "BOINCActivity.determineStatus error: ", e)
-            }
+            Log.e(Logging.TAG, "BOINCActivity.determineStatus error: ", e)
         }
     }
 
@@ -343,18 +332,15 @@ class BOINCActivity : AppCompatActivity() {
     }
 
     override fun onCreateOptionsMenu(menu: Menu): Boolean {
-        if (Logging.DEBUG) {
-            Log.d(Logging.TAG, "BOINCActivity onCreateOptionsMenu()")
-        }
+        Log.d(Logging.TAG, "BOINCActivity onCreateOptionsMenu()")
+
         val inflater = menuInflater
         inflater.inflate(R.menu.main_menu, menu)
         return true
     }
 
     override fun onPrepareOptionsMenu(menu: Menu): Boolean {
-        if (Logging.DEBUG) {
-            Log.d(Logging.TAG, "BOINCActivity onPrepareOptionsMenu()")
-        }
+        Log.d(Logging.TAG, "BOINCActivity onPrepareOptionsMenu()")
 
         // run mode, set title and icon based on status
         val runMode = menu.findItem(R.id.run_mode)
@@ -371,9 +357,7 @@ class BOINCActivity : AppCompatActivity() {
     }
 
     override fun onOptionsItemSelected(item: MenuItem): Boolean {
-        if (Logging.DEBUG) {
-            Log.d(Logging.TAG, "BOINCActivity onOptionsItemSelected()")
-        }
+        Log.d(Logging.TAG, "BOINCActivity onOptionsItemSelected()")
 
         // toggle drawer
         return if (mDrawerToggle.onOptionsItemSelected(item)) {
@@ -382,22 +366,20 @@ class BOINCActivity : AppCompatActivity() {
             R.id.run_mode -> {
                 when {
                     item.title == application.getString(R.string.menu_run_mode_disable) -> {
-                        if (Logging.DEBUG) {
-                            Log.d(Logging.TAG, "run mode: disable")
-                        }
+                        Log.d(Logging.TAG, "run mode: disable")
+
                         lifecycleScope.launch {
                             writeClientMode(RUN_MODE_NEVER)
                         }
                     }
                     item.title == application.getString(R.string.menu_run_mode_enable) -> {
-                        if (Logging.DEBUG) {
-                            Log.d(Logging.TAG, "run mode: enable")
-                        }
+                        Log.d(Logging.TAG, "run mode: enable")
+
                         lifecycleScope.launch {
                             writeClientMode(RUN_MODE_AUTO)
                         }
                     }
-                    Logging.DEBUG -> {
+                    else -> {
                         Log.d(Logging.TAG, "run mode: unrecognized command")
                     }
                 }
@@ -428,25 +410,23 @@ class BOINCActivity : AppCompatActivity() {
         supportActionBar!!.title = mTitle
     }
 
-    private suspend fun writeClientMode(mode: Int) {
+    private fun writeClientMode(mode: Int) {
         val success = writeClientModeAsync(mode)
 
         if (success) {
             try {
                 monitor!!.forceRefresh()
             } catch (e: RemoteException) {
-                if (Logging.ERROR) {
                     Log.e(Logging.TAG, "BOINCActivity.writeClientMode() error: ", e)
-                }
             }
-        } else if (Logging.WARNING) {
+        } else {
             Log.w(Logging.TAG, "BOINCActivity setting run and network mode failed")
         }
     }
 
     companion object {
         @JvmField
-        var monitor: IMonitor? = null
+        var monitor: MonitorAsync? = null
         var mIsBound = false
     }
 }
