@@ -1,7 +1,7 @@
 /*
  * This file is part of BOINC.
  * http://boinc.berkeley.edu
- * Copyright (C) 2020 University of California
+ * Copyright (C) 2021 University of California
  *
  * BOINC is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License
@@ -22,7 +22,6 @@ import android.util.Log
 import android.view.LayoutInflater
 import android.view.View
 import android.view.ViewGroup
-import androidx.core.content.ContextCompat
 import androidx.fragment.app.FragmentActivity
 import androidx.recyclerview.widget.RecyclerView
 import edu.berkeley.boinc.R
@@ -42,10 +41,9 @@ class BatchConflictRecyclerViewAdapter(
 
     override fun onBindViewHolder(holder: ViewHolder, position: Int) {
         val listItem = entries[position]
-        if (Logging.VERBOSE) {
-            Log.d(Logging.TAG, "BatchConflictListAdapter.getView for: ${listItem.name} at" +
-                    " position: $position with result: ${listItem.result}")
-        }
+
+        Log.d(Logging.TAG, "BatchConflictListAdapter.getView for: ${listItem.name} at" +
+                " position: $position with result: ${listItem.result}")
 
         holder.name.text = listItem.name
         if (listItem.result == ProjectAttachService.RESULT_SUCCESS) {
@@ -54,7 +52,7 @@ class BatchConflictRecyclerViewAdapter(
             holder.resolveButtonImage.visibility = View.GONE
             holder.statusProgressBar.visibility = View.GONE
             holder.statusImage.visibility = View.VISIBLE
-            holder.statusImage.setImageDrawable(ContextCompat.getDrawable(activity, R.drawable.ic_baseline_check))
+            holder.statusImage.setImageResource(R.drawable.ic_baseline_check)
         } else if (listItem.result == ProjectAttachService.RESULT_ONGOING ||
                 listItem.result == ProjectAttachService.RESULT_UNINITIALIZED) {
             // ongoing
@@ -68,9 +66,8 @@ class BatchConflictRecyclerViewAdapter(
             holder.status.text = listItem.resultDescription
             holder.resolveButtonImage.visibility = View.VISIBLE
             holder.resolveItemWrapper.setOnClickListener {
-                if (Logging.DEBUG) {
-                    Log.d(Logging.TAG, "BatchConflictListAdapter: start resolution dialog for: " + listItem.name)
-                }
+                Log.d(Logging.TAG, "BatchConflictListAdapter: start resolution dialog for: " + listItem.name)
+
                 val dialog = IndividualCredentialInputFragment.newInstance(listItem)
                 dialog.show(activity.supportFragmentManager, listItem.name)
             }
@@ -82,26 +79,25 @@ class BatchConflictRecyclerViewAdapter(
             holder.resolveButtonImage.visibility = View.GONE
             holder.statusProgressBar.visibility = View.GONE
             holder.statusImage.visibility = View.VISIBLE
-            holder.statusImage.setImageDrawable(ContextCompat.getDrawable(activity, R.drawable.ic_baseline_clear))
+            holder.statusImage.setImageResource(R.drawable.ic_baseline_clear)
         } else {
             // failed
             holder.status.visibility = View.VISIBLE
             holder.status.text = listItem.resultDescription
             holder.resolveButtonImage.visibility = View.VISIBLE
             holder.resolveItemWrapper.setOnClickListener {
-                if (Logging.DEBUG) {
-                    Log.d(Logging.TAG, "BatchConflictListAdapter: start resolution dialog for: " + listItem.name)
-                }
+                Log.d(Logging.TAG, "BatchConflictListAdapter: start resolution dialog for: " + listItem.name)
+
                 val dialog = IndividualCredentialInputFragment.newInstance(listItem)
                 dialog.show(activity.supportFragmentManager, listItem.name)
             }
             holder.statusProgressBar.visibility = View.GONE
             holder.statusImage.visibility = View.VISIBLE
-            holder.statusImage.setImageDrawable(ContextCompat.getDrawable(activity, R.drawable.ic_baseline_clear))
+            holder.statusImage.setImageResource(R.drawable.ic_baseline_clear)
         }
     }
 
-    inner class ViewHolder(binding: AttachProjectBatchConflictsListItemBinding):
+    class ViewHolder(binding: AttachProjectBatchConflictsListItemBinding):
             RecyclerView.ViewHolder(binding.root) {
         val name = binding.name
         val status = binding.status
