@@ -1065,7 +1065,9 @@ int ACTIVE_TASK::start(bool test) {
 
         // hook up stderr to a specially-named file
         //
-        (void) freopen(STDERR_FILE, "a", stderr);
+        if (freopen(STDERR_FILE, "a", stderr) == NULL) {
+            _exit(errno);
+        }
 
         // lower our priority if needed
         //
@@ -1249,9 +1251,6 @@ void run_test_app() {
     RESULT result;
     int retval;
 
-    char buf[256];
-    getcwd(buf, sizeof(buf));   // so we can see where we're running
-
     gstate.run_test_app = true;
 
     wu.project = &project;
