@@ -81,7 +81,7 @@ int dhrystone(
 ){
         One_Fifty       Int_1_Loc;
   REG   One_Fifty       Int_2_Loc;
-        One_Fifty       Int_3_Loc;
+        One_Fifty       Int_3_Loc=0;
   REG   char            Ch_Index;
         Enumeration     Enum_Loc;
         Str_30          Str_1_Loc;
