@@ -41,6 +41,10 @@
 #include <cstring>
 #endif
 
+#ifdef __GLIBC__
+#include <gnu/libc-version.h>
+#endif
+
 #if HAVE_XSS
 #include <X11/extensions/scrnsaver.h> //X-based idle detection
 // prevents naming collision between X.h define of Always and boinc's
@@ -105,6 +109,10 @@
 #include "win/opt_x86.h"
 #endif
 
+#ifdef ARMV6
+#include <sys/wait.h>
+#endif
+
 #include "error_numbers.h"
 #include "common_defs.h"
 #include "filesys.h"
@@ -231,11 +239,11 @@ bool HOST_INFO::host_is_running_on_batteries() {
 
 #elif LINUX_LIKE_SYSTEM
     static enum {
-      Detect,
-      ProcAPM,
-      ProcACPI,
-      SysClass,
-      NoBattery
+        Detect,
+        ProcAPM,
+        ProcACPI,
+        SysClass,
+        NoBattery
     } method = Detect;
     static char path[64] = "";
 
@@ -290,8 +298,11 @@ bool HOST_INFO::host_is_running_on_batteries() {
             );
             fsys = fopen(path, "r");
             if (!fsys) continue;
-            (void) fgets(buf, sizeof(buf), fsys);
+            char *p = fgets(buf, sizeof(buf), fsys);
             fclose(fsys);
+            if (p == NULL) {
+                break;
+            }
             // AC adapters have type "Mains"
             if ((strstr(buf, "mains") != NULL) || (strstr(buf, "Mains") != NULL)) {
                 method = SysClass;
@@ -323,7 +334,7 @@ bool HOST_INFO::host_is_running_on_batteries() {
             int     apm_ac_line_status=1;
 
             // supposedly we're on batteries if the 5th entry is zero.
-            (void) fscanf(fapm, "%10s %d.%d %x %x",
+            int n = fscanf(fapm, "%10s %d.%d %x %x",
                 apm_driver_version,
                 &apm_major_version,
                 &apm_minor_version,
@@ -332,6 +343,7 @@ bool HOST_INFO::host_is_running_on_batteries() {
             );
 
             fclose(fapm);
+            if (n != 5) return false;
 
             return (apm_ac_line_status == 0);
         }
@@ -342,13 +354,15 @@ bool HOST_INFO::host_is_running_on_batteries() {
             if (!facpi) return false;
 
             char buf[128];
-            (void) fgets(buf, sizeof(buf), facpi);
+            char *p = fgets(buf, sizeof(buf), facpi);
 
             fclose(facpi);
+            if (p == NULL) return false;
 
-            if ((strstr(buf, "state:") != NULL) || (strstr(buf, "Status:") != NULL))
+            if ((strstr(buf, "state:") != NULL) || (strstr(buf, "Status:") != NULL)) {
                 // on batteries if ac adapter is "off-line" (or maybe "offline")
                 return (strstr(buf, "off") != NULL);
+            }
 
             return false;
         }
@@ -359,8 +373,9 @@ bool HOST_INFO::host_is_running_on_batteries() {
             if (!fsys) return false;
 
             int online;
-            (void) fscanf(fsys, "%d", &online);
+            int n = fscanf(fsys, "%d", &online);
             fclose(fsys);
+            if (n != 1) return false;
 
             // online is 1 if on AC power, 0 if on battery
             return (0 == online);
@@ -383,10 +398,12 @@ bool HOST_INFO::host_is_running_on_batteries() {
         for (devn = 0;; devn++) {
             mib[2] = devn;
             if (sysctl(mib, 3, &snsrdev, &sdlen, NULL, 0) == -1) {
-                if (errno == ENXIO)
+                if (errno == ENXIO) {
                     continue;
-                if (errno == ENOENT)
+                }
+                if (errno == ENOENT) {
                     break;
+                }
             }
             if (!strcmp("acpiac0", snsrdev.xname)) {
                 break;
@@ -397,11 +414,12 @@ bool HOST_INFO::host_is_running_on_batteries() {
     }
 
     if (sysctl(mib, 5, &s, &slen, NULL, 0) != -1) {
-        if (s.value)
+        if (s.value) {
             // AC present
             return false;
-        else
+        } else {
             return true;
+        }
     }
 
     return false;
@@ -410,11 +428,12 @@ bool HOST_INFO::host_is_running_on_batteries() {
     size_t len = sizeof(ac);
 
     if (sysctlbyname("hw.acpi.acline", &ac, &len, NULL, 0) != -1) {
-        if (ac)
+        if (ac) {
             // AC present
             return false;
-        else
+        } else {
             return true;
+        }
     }
 
     return false;
@@ -956,20 +975,24 @@ static void get_cpu_info_haiku(HOST_INFO& host) {
     }
 
     snprintf(host.p_vendor, sizeof(host.p_vendor), "%.12s",
-        cpuInfo.eax_0.vendor_id);
+        cpuInfo.eax_0.vendor_id
+    );
 
     maxStandardFunction = cpuInfo.eax_0.max_eax;
-    if (maxStandardFunction >= 500)
-        maxStandardFunction = 0; /* old Pentium sample chips has
-                                    cpu signature here */
+    if (maxStandardFunction >= 500) {
+        // old Pentium sample chips has cpu signature here
+        maxStandardFunction = 0;
+    }
 
-    /* Extended cpuid */
+    // Extended cpuid
     get_cpuid(&cpuInfo, 0x80000000, cpu);
 
     // extended cpuid is only supported if max_eax is greater
     // than the service id
-    if (cpuInfo.eax_0.max_eax > 0x80000000)
+    //
+    if (cpuInfo.eax_0.max_eax > 0x80000000) {
         maxExtendedFunction = cpuInfo.eax_0.max_eax & 0xff;
+    }
 
     if (maxExtendedFunction >=4 ) {
         char buffer[49];
@@ -991,8 +1014,9 @@ static void get_cpu_info_haiku(HOST_INFO& host) {
 
         // cut off leading spaces (names are right aligned)
         name = buffer;
-        while (name[0] == ' ')
+        while (name[0] == ' ') {
             name++;
+        }
 
         // the BIOS may not have set the processor name
         if (name[0]) {
@@ -1000,7 +1024,8 @@ static void get_cpu_info_haiku(HOST_INFO& host) {
         } else {
             // Intel CPUs don't seem to have the genuine vendor field
             snprintf(brand_string, sizeof(brand_string), "%.12s",
-                cpuInfo.eax_0.vendor_id);
+                cpuInfo.eax_0.vendor_id
+            );
         }
     }
 
@@ -1024,7 +1049,8 @@ static void get_cpu_info_haiku(HOST_INFO& host) {
 
     snprintf(host.p_model, sizeof(host.p_model),
         "%s [Family %u Model %u Stepping %u]", brand_string, family, model,
-        stepping);
+        stepping
+    );
 
     static const char *kFeatures[32] = {
         "fpu", "vme", "de", "pse",
@@ -1044,7 +1070,8 @@ static void get_cpu_info_haiku(HOST_INFO& host) {
     for (i = 0; i < 32; i++) {
         if ((cpuInfo.eax_1.features & (1UL << i)) && kFeatures[i] != NULL) {
             snprintf(buf, sizeof(buf), "%s%s", found == 0 ? "" : " ",
-                kFeatures[i]);
+                kFeatures[i]
+            );
             strlcat(host.p_features, buf, sizeof(host.p_features));
             found++;
         }
@@ -1063,7 +1090,8 @@ static void get_cpu_info_haiku(HOST_INFO& host) {
             if ((cpuInfo.eax_1.extended_features & (1UL << i)) &&
                 kFeatures2[i] != NULL) {
                 snprintf(buf, sizeof(buf), "%s%s", found == 0 ? "" : " ",
-                    kFeatures2[i]);
+                    kFeatures2[i]
+                );
                 strlcat(host.p_features, buf, sizeof(host.p_features));
                 found++;
             }
@@ -1458,6 +1486,12 @@ int HOST_INFO::get_memory_info() {
 // return BOINC_SUCCESS if at least version could be found (extra_info may remain empty)
 // return ERR_NOT_FOUND if ldd couldn't be opened or no version information was found
 //
+#ifdef __GLIBC__
+int get_libc_version(string& version, string&) {
+    version = string(gnu_get_libc_version());
+    return BOINC_SUCCESS;
+}
+#else
 int get_libc_version(string& version, string& extra_info) {
     char buf[1024] = "";
     string strbuf;
@@ -1493,6 +1527,7 @@ int get_libc_version(string& version, string& extra_info) {
     return BOINC_SUCCESS;
 }
 #endif
+#endif
 
 // get os_name, os_version
 //
@@ -1654,15 +1689,24 @@ inline long device_idle_time(const char *device) {
 static const struct dir_tty_dev {
     const char *dir;
     const char *dev;
+    const vector<string> ignore_list;
+
+    bool should_ignore(const string &devname) const {
+        for (const string &ignore : ignore_list) {
+            if (devname.rfind(ignore, 0) == 0) return true;
+        }
+        return false;
+    }
 } tty_patterns[] = {
-#ifdef unix
-    { "/dev", "tty" },
-    { "/dev", "pty" },
-    { "/dev/pts", NULL },
+#if defined(LINUX_LIKE_SYSTEM) and !defined(ANDROID)
+    { "/dev", "tty",
+      {"ttyS", "ttyACM"},
+    },
+    { "/dev", "pty", {}},
+    { "/dev/pts", NULL, {}},
 #endif
-    // add other ifdefs here as necessary.
-    { NULL, NULL },
 };
+#define N_TTY_PATTERNS sizeof(tty_patterns)/sizeof(dir_tty_dev)
 
 // Make a list of all TTY devices on the system.
 //
@@ -1671,8 +1715,7 @@ vector<string> get_tty_list() {
     char fullname[1024];
     vector<string> tty_list;
 
-    for (int i=0; ; i++) {
-        if (tty_patterns[i].dir == NULL) break;
+    for (unsigned int i=0; i<N_TTY_PATTERNS; i++) {
         DIRREF dev = dir_open(tty_patterns[i].dir);
         if (!dev) continue;
         while (1) {
@@ -1683,6 +1726,12 @@ vector<string> get_tty_list() {
             //
             if (tty_patterns[i].dev) {
                 if ((strstr(devname, tty_patterns[i].dev) != devname)) continue;
+
+                // Ignore some devices. This could be, for example,
+                // ttyS* (serial port) or devACM* (serial USB) devices
+                // which may be used even without a user being active.
+                //
+                if (tty_patterns[i].should_ignore(devname)) continue;
             }
 
             sprintf(fullname, "%s/%s", tty_patterns[i].dir, devname);
@@ -1706,12 +1755,15 @@ vector<string> get_tty_list() {
 
 inline long all_tty_idle_time() {
     static vector<string> tty_list;
+    static bool first = true;
     struct stat sbuf;
-    unsigned int i;
     long idle_time = USER_IDLE_TIME_INF;
 
-    if (tty_list.size()==0) tty_list=get_tty_list();
-    for (i=0; i<tty_list.size(); i++) {
+    if (first) {
+        first = false;
+        tty_list = get_tty_list();
+    }
+    for (unsigned int i=0; i<tty_list.size(); i++) {
         // ignore errors
         if (!stat(tty_list[i].c_str(), &sbuf)) {
             // printf("tty: %s %d %d\n",tty_list[i].c_str(), sbuf.st_atime, t);
@@ -1726,6 +1778,7 @@ inline long all_tty_idle_time() {
 // We can't link the client with the AppKit framework because the client
 // must be setuid boinc_master. So the client uses this to get the system
 // up time instead of our getTimeSinceBoot() function in lib/mac_util.mm.
+//
 int get_system_uptime() {
     struct timeval tv;
     size_t len = sizeof(tv);
@@ -1795,7 +1848,7 @@ long HOST_INFO::user_idle_time(bool /*check_all_logins*/) {
     } else {
         // When the system first starts up, allow time for HIDSystem to be available if needed
         if (get_system_uptime() > (120)) {   // If system has been up for more than 2 minutes
-             msg_printf(NULL, MSG_INFO,
+            msg_printf(NULL, MSG_INFO,
                 "Could not connect to HIDSystem: user idle detection is disabled."
             );
             error_posted = true;
@@ -1804,8 +1857,9 @@ long HOST_INFO::user_idle_time(bool /*check_all_logins*/) {
     }
 
     if (!gstate.executing_as_daemon) {
-        idleTimeFromCG =  CGEventSourceSecondsSinceLastEventType
-                (kCGEventSourceStateCombinedSessionState, kCGAnyInputEventType);
+        idleTimeFromCG =  CGEventSourceSecondsSinceLastEventType (
+            kCGEventSourceStateCombinedSessionState, kCGAnyInputEventType
+        );
 
         if (idleTimeFromCG < idleTime) {
             idleTime = idleTimeFromCG;
@@ -2082,6 +2136,7 @@ union headeru {
     fat_header fat;
     mach_header mach;
 };
+
 // Get the architecture of this computer's CPU: x86_64 or arm64.
 // Read the executable file's mach-o headers to determine the 
 // architecture(s) of its code.
@@ -2092,7 +2147,6 @@ union headeru {
 // properly run under Rosetta 2. Note: years ago, PowerPC apps emulated 
 // by Rosetta on i386 Macs crashed when running graphics.
 //
-
 bool can_run_on_this_CPU(char* exec_path) {
     FILE *f;
     int retval = false;
