@@ -792,7 +792,7 @@ void boinc_catch_signal(int signal) {
     size = backtrace (array, 64);
 //  Anything that calls malloc here (i.e *printf()) will probably fail
 //  so we'll do it the hard way.
-    (void) write(fileno(stderr),"Stack trace (",strlen("Stack trace ("));
+    int retval = write(fileno(stderr),"Stack trace (",strlen("Stack trace ("));
     char mbuf[10];
     char *p=mbuf+9;
     int i=size;
@@ -801,11 +801,12 @@ void boinc_catch_signal(int signal) {
       *(p--)=i%10+'0';
       i/=10;
     }
-    (void) write(fileno(stderr),p+1,strlen(p+1));
-    (void) write(fileno(stderr)," frames):",strlen(" frames):"));
+    retval = write(fileno(stderr),p+1,strlen(p+1));
+    retval = write(fileno(stderr)," frames):",strlen(" frames):"));
     mbuf[0]=10;
-    (void) write(fileno(stderr),mbuf,1);
+    retval = write(fileno(stderr),mbuf,1);
     backtrace_symbols_fd(array, size, fileno(stderr));
+    if (retval) {}
 #endif
 
 #ifdef __APPLE__
