@@ -18,9 +18,6 @@
 // Support for plan classes defined using an XML file.
 // See https://boinc.berkeley.edu/trac/wiki/AppPlanSpec
 
-// logic for handling an XML specification of plan classes
-// see https://boinc.berkeley.edu/trac/wiki/AppPlanConfig
-
 #include <cmath>
 
 #include "util.h"
@@ -32,7 +29,7 @@
 
 using std::string;
 
-// this returns a numerical OS version for Darwin/OSX and Windows,
+// return a numerical OS version for Darwin/OSX and Windows,
 // letting us define numerical ranges for these OS versions
 //
 static double os_version_num(HOST h) {
@@ -48,12 +45,35 @@ static double os_version_num(HOST h) {
         if (p && (sscanf(p, "(%u.%u.%u.%u)", &a, &b, &c, &d) == 4)) {
             return 100000000.0*a + 1000000.0*b + 100.0*c +d;
         }
-    } else if (strstr(h.os_name, "Android") || strstr(h.os_name, "Linux")) {
-        // example: 3.0.31-g6fb96c9
+    } else if (strstr(h.os_name, "Android")) {
+        // examples:
+        // 3.0.31-g6fb96c9
+        // 2.6.36.3
+        // 3.4.0
         //
         if (sscanf(h.os_version, "%u.%u.%u", &a, &b, &c) == 3) {
             return 10000.*a + 100.*b + c;
         }
+    } else if (strstr(h.os_name, "Linux")) {
+        // os_name seems to always contain "Linux".
+        // os_version is pretty diverse:
+        //
+        // Linux Mint 19 Tara [4.18.12-041812-generic|libc 2.27 (Ubuntu GLIBC 2.27-3ubuntu1)]
+        // CentOS Linux 7 (Core) [3.10.0-862.14.4.el7.x86_64|libc 2.17 (GNU libc)]
+        // Ubuntu 18.04.1 LTS [4.15.0-36-generic|libc 2.27 (Ubuntu GLIBC 2.27-3ubuntu1)]
+        // 3.13.0-103-generic
+        // 4.9.0-8-amd64
+        // Manjaro Linux [4.19.42-1-MANJARO|libc 2.29 (GNU libc)]
+
+        char* p = strchr(h.os_version, '[');
+        if (p) {
+            p++;
+        } else {
+            p = h.os_version;
+        }
+        if (sscanf(p, "%u.%u.%u", &a, &b, &c) == 3) {
+            return 10000.*a + 100.*b + c;
+        }
     }
     // could not determine numerical OS version
     //
@@ -82,7 +102,9 @@ static int android_version_num(HOST h) {
     return 0;
 }
 
-static bool wu_is_infeasible_for_plan_class(const PLAN_CLASS_SPEC* pc, const WORKUNIT* wu) {
+static bool wu_is_infeasible_for_plan_class(
+    const PLAN_CLASS_SPEC* pc, const WORKUNIT* wu
+) {
     if (pc->min_wu_id && wu->id < pc->min_wu_id) {
         if (config.debug_version_select) {
             log_messages.printf(MSG_NORMAL,
@@ -104,7 +126,7 @@ static bool wu_is_infeasible_for_plan_class(const PLAN_CLASS_SPEC* pc, const WOR
     if (pc->min_batch && wu->batch < pc->min_batch) {
         if (config.debug_version_select) {
             log_messages.printf(MSG_NORMAL,
-                "[version] batch#%ld too old for plan class '%s' (%ld)\n",
+                "[version] batch#%d too old for plan class '%s' (%ld)\n",
                 wu->batch, pc->name, pc->min_batch
             );
         }
@@ -113,7 +135,7 @@ static bool wu_is_infeasible_for_plan_class(const PLAN_CLASS_SPEC* pc, const WOR
     if (pc->max_batch && wu->batch > pc->max_batch) {
         if (config.debug_version_select) {
             log_messages.printf(MSG_NORMAL,
-                "[version] batch#%ld too new for plan class '%s' (%ld)\n",
+                "[version] batch#%d too new for plan class '%s' (%ld)\n",
                 wu->batch, pc->name, pc->max_batch
             );
         }
@@ -198,7 +220,9 @@ bool PLAN_CLASS_SPEC::opencl_check(OPENCL_DEVICE_PROP& opencl_prop) {
 // See whether the given host/user can be sent this plan class.
 // If so return the resource usage and estimated FLOPS in hu.
 //
-bool PLAN_CLASS_SPEC::check(SCHEDULER_REQUEST& sreq, HOST_USAGE& hu, const WORKUNIT* wu) {
+bool PLAN_CLASS_SPEC::check(
+    SCHEDULER_REQUEST& sreq, HOST_USAGE& hu, const WORKUNIT* wu
+) {
     COPROC* cpp = NULL;
     bool can_use_multicore = true;
     string msg;
@@ -981,11 +1005,11 @@ bool PLAN_CLASS_SPEC::check(SCHEDULER_REQUEST& sreq, HOST_USAGE& hu, const WORKU
 #endif
 
     return true;
-
 }
 
 bool PLAN_CLASS_SPECS::check(
-    SCHEDULER_REQUEST& sreq, char* plan_class, HOST_USAGE& hu, const WORKUNIT* wu
+    SCHEDULER_REQUEST& sreq, char* plan_class, HOST_USAGE& hu,
+    const WORKUNIT* wu
 ) {
     for (unsigned int i=0; i<classes.size(); i++) {
         if (!strcmp(classes[i].name, plan_class)) {
@@ -996,7 +1020,9 @@ bool PLAN_CLASS_SPECS::check(
     return false;
 }
 
-bool PLAN_CLASS_SPECS::wu_is_infeasible(char* plan_class_name, const WORKUNIT* wu) {
+bool PLAN_CLASS_SPECS::wu_is_infeasible(
+    char* plan_class_name, const WORKUNIT* wu
+) {
     if(wu_restricted_plan_class) {
         for (unsigned int i=0; i<classes.size(); i++) {
             if(!strcmp(classes[i].name, plan_class_name)) {
